<?php

namespace App\Gateway;

use App\Connexion;
use PDO;

class TeamGateway {
    private Connexion $con;

    public function __construct(Connexion $con) {
        $this->con = $con;
    }

    public function insert(string $name, string $picture, string $mainColor, string $secondColor): void {
        $this->con->exec(
            "INSERT INTO Team(name, picture, mainColor, secondColor) VALUES (:teamName , :picture, :mainColor, :secondColor)",
            [
                ":teamName" => [$name, PDO::PARAM_STR],
                ":picture" => [$picture, PDO::PARAM_STR],
                ":mainColor" => [$mainColor, PDO::PARAM_STR],
                ":secondColor" => [$secondColor, PDO::PARAM_STR],
            ]
        );
    }


    public function insertMember(int $idTeam, int $idMember, string $role) {
        $this->con->exec(
            "INSERT INTO Member(idTeam, idMember, role) VALUES (:idTeam , :idMember, :role)",
            [
                ":idTeam" => [$idTeam, PDO::PARAM_INT],
                ":idMember" => [$idMember, PDO::PARAM_INT],
                ":role" => [$role, PDO::PARAM_STR]
            ]
        );
    }


    public function listByName(string $name): array {
        return $this->con->fetch(
            "SELECT id,name,picture,mainColor,secondColor FROM Team WHERE name LIKE '%' || :name || '%'",
            [
                ":name" => [$name, PDO::PARAM_STR],
            ]
        );
    }

    /**
     * @param int $id
     * @return array<string,mixed>[]
     */
    public function getTeamById(int $id): array {
        return $this->con->fetch(
            "SELECT id,name,picture,mainColor,secondColor FROM Team WHERE id = :id",
            [
                ":id" => [$id, PDO::PARAM_INT],
            ]
        );
    }

    /**
     * @param string $name
     * @return array<string,int>[]
     */
    public function getIdTeamByName(string $name): array {
        return $this->con->fetch(
            "SELECT id FROM Team WHERE name = :name",
            [
                ":name" => [$name, PDO::PARAM_STR],
            ]
        );
    }

    /**
     * @param int $id
     * @return array<string,mixed>[]
     */
    public function getMembersById(int $id): array {
        return $this->con->fetch(
          "SELECT a.id,m.role,a.email,a.username FROM Account a,Team t,Member m WHERE t.id = :id AND m.idTeam = t.id AND m.idMember = a.id",
          [
              ":id" => [$id, PDO::PARAM_INT]
          ]
        );
    }

    public function getMemberIdByMail($mail) : array {
        return $this->con->fetch(
            "SELECT id FROM Account WHERE email = :mail",
            [
                ":mail" => [$mail, PDO::PARAM_STR]
            ]
        );
    }

    public function deleteMember(int $idTeam, int $idMember) {
        $this->con->exec(
            "DELETE FROM Member WHERE idTeam = :idTeam AND idMember = :idMember",
            [
                ":idTeam" => [$idTeam, PDO::PARAM_INT],
                ":idMember" => [$idMember, PDO::PARAM_INT],
            ]
        );
    }

}
