<?php

namespace App\Model;

use App\Gateway\TeamGateway;
use App\Data\Team;
use App\Data\Member;
use App\Data\MemberRole;
use App\Data\Color;

class TeamModel {
    private TeamGateway $gateway;

    /**
     * @param TeamGateway $gateway
     */
    public function __construct(TeamGateway $gateway) {
        $this->gateway = $gateway;
    }

    public function createTeam(string $name, string $picture, string $mainColor, string $secondColor): int {
        $this->gateway->insert($name, $picture, $mainColor, $secondColor);
        $result = $this->gateway->getIdTeamByName($name);
        return intval($result[0]['id']);
    }


    public function addMember(string $mail, int $teamId, string $role) : int {
        $result = $this->gateway->getMemberIdByMail($mail)[0];
        $memberId = intval($result['id']);
        $this->gateway->insertMember($teamId, $memberId, $role);
        return $teamId;
    }

    public function listByName(string $name): array {
        $teams = [];
        $results = $this->gateway->listByName($name);
        foreach ($results as $row) {
            $teams[] = new Team($row['id'], $row['name'], $row['picture'], Color::from($row['mainColor']), Color::from($row['secondColor']));
        }
        return $teams;
    }

    public function displayTeam(int $id): Team {
        $members = [];
        $result = $this->gateway->getTeamById($id)[0];
        $resultMembers = $this->gateway->getMembersById($id);
        foreach ($resultMembers as $row) {
            var_dump($row['role']);
            if ($row['role'] == 'C') {
                $role = MemberRole::coach();
            } else {
                $role = MemberRole::player();
            }
            $members[] = new Member($row['id'], $id, $role);
        }
        return new Team(intval($result['id']), $result['name'], $result['picture'], Color::from($result['mainColor']), Color::from($result['secondColor']), $members);
    }

    public function deleteMember(string $mail, int $teamId) : int {
        $result = $this->gateway->getMemberIdByMail($mail)[0];
        $memberId = intval($result['id']);
        $this->gateway->deleteMember($teamId, $memberId);
        return $teamId;
    }

}
